Huffman code
============

(From https://github.com/ALikhachev/Huffman-code)

Program is designed to use basic archiving algorithm based on Huffman code for encoding & decoding files.

Usage: `<binname.ext> [mode] [input filename] [output filename]`
where mode may be:
                e for encoding
                qe for fast encoding
                d for decoding
